===========
cnt.rulebase
===========


.. image:: https://img.shields.io/pypi/v/cnt.rulebase.svg
        :target: https://pypi.python.org/pypi/cnt.rulebase

.. image:: https://img.shields.io/travis/cnt-dev/cnt.rulebase.svg
        :target: https://travis-ci.org/cnt-dev/cnt.rulebase

.. image:: https://readthedocs.org/projects/cnt-rulebase/badge/?version=latest
        :target: https://cnt-rulebase.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




None


* Free software: MIT license
* Documentation: https://cnt-rulebase.readthedocs.io.


Features
--------

:mod:`cnt.rulebase` is designed as rule-based toolkit for *Chinese* NLP tasks. Supported features:

- Sentence segmentation: :func:`cnt.rulebase.sentseg` and :func:`cnt.rulebase.sentseg_lazy`.
- Pattern filtering: :obj:`cnt.rulebase.collector`.
- Pattern replacement: :obj:`cnt.rulebase.replacer`.

Example :ref:`usage_label`.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
